"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
const node_path_1 = __importDefault(require("node:path"));
const eslint_mdx_1 = require("eslint-mdx");
const create_storybook_rule_1 = require("../utils/create-storybook-rule");
const constants_1 = require("../utils/constants");
module.exports = (0, create_storybook_rule_1.createStorybookRule)({
    //@ts-ignore
    meta: {
        type: 'problem',
        docs: {
            description: 'Meta should only have inline properties',
            categories: [constants_1.CategoryId.CSF, constants_1.CategoryId.RECOMMENDED],
            excludeFromConfig: true,
            recommended: 'error',
        },
        fixable: 'code',
        // messages: {
        //   hey: 'DJ'
        // },
        schema: [],
    },
    create(context) {
        const filename = context.getFilename();
        const extname = node_path_1.default.extname(filename);
        const sourceCode = context.getSourceCode();
        const options = context.parserOptions;
        const isMdx = [...eslint_mdx_1.DEFAULT_EXTENSIONS, ...(options.extensions || [])].includes(extname);
        return {
            // eslint-disable-next-line sonarjs/cognitive-complexity
            Program(node) {
                /* istanbul ignore if */
                if (!isMdx) {
                    console.log('NOT AN MDX FILE!');
                    return;
                }
                const ignoreRemarkConfig = Boolean(options.ignoreRemarkConfig);
                const physicalFilename = (0, eslint_mdx_1.getPhysicalFilename)(filename);
                const sourceText = sourceCode.getText(node);
                console.log({ ignoreRemarkConfig, physicalFilename, sourceText });
                return;
                // const { messages, content: fixedText } = performSyncWork({
                //   fileOptions: {
                //     path: physicalFilename,
                //     value: sourceText,
                //     cwd: context.getCwd?.(),
                //   },
                //   physicalFilename,
                //   isMdx,
                //   process: true,
                //   ignoreRemarkConfig,
                // })
                // let fixed = 0
                // for (const {
                //   source,
                //   reason,
                //   ruleId,
                //   fatal,
                //   line,
                //   column,
                //   position: { start, end },
                // } of messages) {
                //   // https://github.com/remarkjs/remark-lint/issues/65#issuecomment-220800231
                //   /* istanbul ignore next */
                //   const severity = fatal ? 2 : fatal == null ? 0 : 1
                //   /* istanbul ignore if */
                //   if (!severity) {
                //     // should never happen, just for robustness
                //     continue
                //   }
                //   const message = {
                //     reason,
                //     source,
                //     ruleId,
                //     severity,
                //   }
                //   context.report({
                //     // related to https://github.com/eslint/eslint/issues/14198
                //     message: JSON.stringify(message),
                //     loc: {
                //       line,
                //       // ! eslint ast column is 0-indexed, but unified is 1-indexed
                //       column: column - 1,
                //       start: {
                //         ...start,
                //         column: start.column - 1,
                //       },
                //       end: {
                //         ...end,
                //         column: end.column - 1,
                //       },
                //     },
                //     node,
                //     fix:
                //       fixedText === sourceText
                //         ? null
                //         : () =>
                //             fixed++
                //               ? null
                //               : {
                //                   range: [0, sourceText.length],
                //                   text: fixedText,
                //                 },
                //   })
                // }
            },
        };
    },
});
